# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
IGESToBRep module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_igestobrep.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _IGESToBRep
else:
    import _IGESToBRep

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _IGESToBRep.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _IGESToBRep.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IGESToBRep.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IGESToBRep.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _IGESToBRep.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _IGESToBRep.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _IGESToBRep.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _IGESToBRep.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _IGESToBRep.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _IGESToBRep.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IGESToBRep.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _IGESToBRep.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _IGESToBRep.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IGESToBRep.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IGESToBRep.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IGESToBRep.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _IGESToBRep.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _IGESToBRep:
_IGESToBRep.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _IGESToBRep.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.IGESData
import OCC.Core.Interface
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Transfer
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.ShapeExtend
import OCC.Core.TColGeom
import OCC.Core.TopTools
import OCC.Core.Geom2d

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_IGESToBRep_Actor_Create() -> "opencascade::handle< IGESToBRep_Actor >":
    return _IGESToBRep.Handle_IGESToBRep_Actor_Create()

def Handle_IGESToBRep_Actor_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IGESToBRep_Actor >":
    return _IGESToBRep.Handle_IGESToBRep_Actor_DownCast(t)

def Handle_IGESToBRep_Actor_IsNull(t: "opencascade::handle< IGESToBRep_Actor > const &") -> "bool":
    return _IGESToBRep.Handle_IGESToBRep_Actor_IsNull(t)

def Handle_IGESToBRep_AlgoContainer_Create() -> "opencascade::handle< IGESToBRep_AlgoContainer >":
    return _IGESToBRep.Handle_IGESToBRep_AlgoContainer_Create()

def Handle_IGESToBRep_AlgoContainer_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IGESToBRep_AlgoContainer >":
    return _IGESToBRep.Handle_IGESToBRep_AlgoContainer_DownCast(t)

def Handle_IGESToBRep_AlgoContainer_IsNull(t: "opencascade::handle< IGESToBRep_AlgoContainer > const &") -> "bool":
    return _IGESToBRep.Handle_IGESToBRep_AlgoContainer_IsNull(t)

def Handle_IGESToBRep_IGESBoundary_Create() -> "opencascade::handle< IGESToBRep_IGESBoundary >":
    return _IGESToBRep.Handle_IGESToBRep_IGESBoundary_Create()

def Handle_IGESToBRep_IGESBoundary_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IGESToBRep_IGESBoundary >":
    return _IGESToBRep.Handle_IGESToBRep_IGESBoundary_DownCast(t)

def Handle_IGESToBRep_IGESBoundary_IsNull(t: "opencascade::handle< IGESToBRep_IGESBoundary > const &") -> "bool":
    return _IGESToBRep.Handle_IGESToBRep_IGESBoundary_IsNull(t)

def Handle_IGESToBRep_ToolContainer_Create() -> "opencascade::handle< IGESToBRep_ToolContainer >":
    return _IGESToBRep.Handle_IGESToBRep_ToolContainer_Create()

def Handle_IGESToBRep_ToolContainer_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IGESToBRep_ToolContainer >":
    return _IGESToBRep.Handle_IGESToBRep_ToolContainer_DownCast(t)

def Handle_IGESToBRep_ToolContainer_IsNull(t: "opencascade::handle< IGESToBRep_ToolContainer > const &") -> "bool":
    return _IGESToBRep.Handle_IGESToBRep_ToolContainer_IsNull(t)
class igestobrep(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AlgoContainer(*args) -> "opencascade::handle< IGESToBRep_AlgoContainer >":
        r"""
        Returns default algocontainer.

        Returns
        -------
        opencascade::handle<IGESToBRep_AlgoContainer>

        """
        return _IGESToBRep.igestobrep_AlgoContainer(*args)

    @staticmethod
    def IGESCurveToSequenceOfIGESCurve(*args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        curve: IGESData_IGESEntity
        sequence: TColStd_HSequenceOfTransient

        Returns
        -------
        int

        """
        return _IGESToBRep.igestobrep_IGESCurveToSequenceOfIGESCurve(*args)

    @staticmethod
    def Init(*args) -> "void":
        r"""
        Creates and initializes default algocontainer.

        Returns
        -------
        None

        """
        return _IGESToBRep.igestobrep_Init(*args)

    @staticmethod
    def IsBRepEntity(*args) -> "Standard_Boolean":
        r"""
        Return true if the igesentity can be transfered by transferbrepentity. ex: vertexlist, edgelist, loop, face, shell, manifold solid brep object from igessolid : 502, 504, 508, 510, 514, 186.

        Parameters
        ----------
        start: IGESData_IGESEntity

        Returns
        -------
        bool

        """
        return _IGESToBRep.igestobrep_IsBRepEntity(*args)

    @staticmethod
    def IsBasicCurve(*args) -> "Standard_Boolean":
        r"""
        Return true if the igesentity can be transfered by transferbasiccurve. ex: circulararc, conicarc, line, copiousdata, bsplinecurve, splinecurve... from igesgeom : 104,110,112,126.

        Parameters
        ----------
        start: IGESData_IGESEntity

        Returns
        -------
        bool

        """
        return _IGESToBRep.igestobrep_IsBasicCurve(*args)

    @staticmethod
    def IsBasicSurface(*args) -> "Standard_Boolean":
        r"""
        Return true if the igesentity can be transfered by transferbasicsurface. ex: bsplinesurface, splinesurface... from igesgeom : 114,128.

        Parameters
        ----------
        start: IGESData_IGESEntity

        Returns
        -------
        bool

        """
        return _IGESToBRep.igestobrep_IsBasicSurface(*args)

    @staticmethod
    def IsCurveAndSurface(*args) -> "Standard_Boolean":
        r"""
        Return true if the igesentity can be transfered by transfercurveandsurface. ex: all igesentity from igesgeom.

        Parameters
        ----------
        start: IGESData_IGESEntity

        Returns
        -------
        bool

        """
        return _IGESToBRep.igestobrep_IsCurveAndSurface(*args)

    @staticmethod
    def IsTopoCurve(*args) -> "Standard_Boolean":
        r"""
        Return true if the igesentity can be transfered by transfertopocurve. ex: all curves from igesgeom : all basic curves,102,130,142,144.

        Parameters
        ----------
        start: IGESData_IGESEntity

        Returns
        -------
        bool

        """
        return _IGESToBRep.igestobrep_IsTopoCurve(*args)

    @staticmethod
    def IsTopoSurface(*args) -> "Standard_Boolean":
        r"""
        Return true if the igesentity can be transfered by transfertoposurface. ex: all surfaces from igesgeom : all basic surfaces,108,118,120,122,141,143.

        Parameters
        ----------
        start: IGESData_IGESEntity

        Returns
        -------
        bool

        """
        return _IGESToBRep.igestobrep_IsTopoSurface(*args)

    @staticmethod
    def SetAlgoContainer(*args) -> "void":
        r"""
        Sets default algocontainer.

        Parameters
        ----------
        aContainer: IGESToBRep_AlgoContainer

        Returns
        -------
        None

        """
        return _IGESToBRep.igestobrep_SetAlgoContainer(*args)

    @staticmethod
    def TransferPCurve(*args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        fromedge: TopoDS_Edge
        toedge: TopoDS_Edge
        face: TopoDS_Face

        Returns
        -------
        bool

        """
        return _IGESToBRep.igestobrep_TransferPCurve(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _IGESToBRep.igestobrep_swiginit(self, _IGESToBRep.new_igestobrep())
    __swig_destroy__ = _IGESToBRep.delete_igestobrep

# Register igestobrep in _IGESToBRep:
_IGESToBRep.igestobrep_swigregister(igestobrep)

def igestobrep_AlgoContainer(*args) -> "opencascade::handle< IGESToBRep_AlgoContainer >":
    r"""
    Returns default algocontainer.

    Returns
    -------
    opencascade::handle<IGESToBRep_AlgoContainer>

    """
    return _IGESToBRep.igestobrep_AlgoContainer(*args)

def igestobrep_IGESCurveToSequenceOfIGESCurve(*args) -> "Standard_Integer":
    r"""
    No available documentation.

    Parameters
    ----------
    curve: IGESData_IGESEntity
    sequence: TColStd_HSequenceOfTransient

    Returns
    -------
    int

    """
    return _IGESToBRep.igestobrep_IGESCurveToSequenceOfIGESCurve(*args)

def igestobrep_Init(*args) -> "void":
    r"""
    Creates and initializes default algocontainer.

    Returns
    -------
    None

    """
    return _IGESToBRep.igestobrep_Init(*args)

def igestobrep_IsBRepEntity(*args) -> "Standard_Boolean":
    r"""
    Return true if the igesentity can be transfered by transferbrepentity. ex: vertexlist, edgelist, loop, face, shell, manifold solid brep object from igessolid : 502, 504, 508, 510, 514, 186.

    Parameters
    ----------
    start: IGESData_IGESEntity

    Returns
    -------
    bool

    """
    return _IGESToBRep.igestobrep_IsBRepEntity(*args)

def igestobrep_IsBasicCurve(*args) -> "Standard_Boolean":
    r"""
    Return true if the igesentity can be transfered by transferbasiccurve. ex: circulararc, conicarc, line, copiousdata, bsplinecurve, splinecurve... from igesgeom : 104,110,112,126.

    Parameters
    ----------
    start: IGESData_IGESEntity

    Returns
    -------
    bool

    """
    return _IGESToBRep.igestobrep_IsBasicCurve(*args)

def igestobrep_IsBasicSurface(*args) -> "Standard_Boolean":
    r"""
    Return true if the igesentity can be transfered by transferbasicsurface. ex: bsplinesurface, splinesurface... from igesgeom : 114,128.

    Parameters
    ----------
    start: IGESData_IGESEntity

    Returns
    -------
    bool

    """
    return _IGESToBRep.igestobrep_IsBasicSurface(*args)

def igestobrep_IsCurveAndSurface(*args) -> "Standard_Boolean":
    r"""
    Return true if the igesentity can be transfered by transfercurveandsurface. ex: all igesentity from igesgeom.

    Parameters
    ----------
    start: IGESData_IGESEntity

    Returns
    -------
    bool

    """
    return _IGESToBRep.igestobrep_IsCurveAndSurface(*args)

def igestobrep_IsTopoCurve(*args) -> "Standard_Boolean":
    r"""
    Return true if the igesentity can be transfered by transfertopocurve. ex: all curves from igesgeom : all basic curves,102,130,142,144.

    Parameters
    ----------
    start: IGESData_IGESEntity

    Returns
    -------
    bool

    """
    return _IGESToBRep.igestobrep_IsTopoCurve(*args)

def igestobrep_IsTopoSurface(*args) -> "Standard_Boolean":
    r"""
    Return true if the igesentity can be transfered by transfertoposurface. ex: all surfaces from igesgeom : all basic surfaces,108,118,120,122,141,143.

    Parameters
    ----------
    start: IGESData_IGESEntity

    Returns
    -------
    bool

    """
    return _IGESToBRep.igestobrep_IsTopoSurface(*args)

def igestobrep_SetAlgoContainer(*args) -> "void":
    r"""
    Sets default algocontainer.

    Parameters
    ----------
    aContainer: IGESToBRep_AlgoContainer

    Returns
    -------
    None

    """
    return _IGESToBRep.igestobrep_SetAlgoContainer(*args)

def igestobrep_TransferPCurve(*args) -> "Standard_Boolean":
    r"""
    No available documentation.

    Parameters
    ----------
    fromedge: TopoDS_Edge
    toedge: TopoDS_Edge
    face: TopoDS_Face

    Returns
    -------
    bool

    """
    return _IGESToBRep.igestobrep_TransferPCurve(*args)

class IGESToBRep_Actor(OCC.Core.Transfer.Transfer_ActorOfTransientProcess):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _IGESToBRep.IGESToBRep_Actor_swiginit(self, _IGESToBRep.new_IGESToBRep_Actor(*args))

    def GetContinuity(self, *args) -> "Standard_Integer":
        r"""
        Return 'thecontinuity'.

        Returns
        -------
        int

        """
        return _IGESToBRep.IGESToBRep_Actor_GetContinuity(self, *args)

    def SetContinuity(self, *args) -> "void":
        r"""
        ---purpose by default continuity = 0 if continuity = 1 : try c1 if continuity = 2 : try c2.

        Parameters
        ----------
        continuity: int,optional
        	default value is 0

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_Actor_SetContinuity(self, *args)

    def SetModel(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        model: Interface_InterfaceModel

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_Actor_SetModel(self, *args)

    def UsedTolerance(self, *args) -> "Standard_Real":
        r"""
        Returns the tolerance which was actually used, either from the file or from statics.

        Returns
        -------
        float

        """
        return _IGESToBRep.IGESToBRep_Actor_UsedTolerance(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_IGESToBRep_Actor_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IGESToBRep.delete_IGESToBRep_Actor

# Register IGESToBRep_Actor in _IGESToBRep:
_IGESToBRep.IGESToBRep_Actor_swigregister(IGESToBRep_Actor)

class IGESToBRep_AlgoContainer(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _IGESToBRep.IGESToBRep_AlgoContainer_swiginit(self, _IGESToBRep.new_IGESToBRep_AlgoContainer(*args))

    def SetToolContainer(self, *args) -> "void":
        r"""
        Sets toolcontainer.

        Parameters
        ----------
        TC: IGESToBRep_ToolContainer

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_AlgoContainer_SetToolContainer(self, *args)

    def ToolContainer(self, *args) -> "opencascade::handle< IGESToBRep_ToolContainer >":
        r"""
        Returns toolcontainer.

        Returns
        -------
        opencascade::handle<IGESToBRep_ToolContainer>

        """
        return _IGESToBRep.IGESToBRep_AlgoContainer_ToolContainer(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_IGESToBRep_AlgoContainer_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IGESToBRep.delete_IGESToBRep_AlgoContainer

# Register IGESToBRep_AlgoContainer in _IGESToBRep:
_IGESToBRep.IGESToBRep_AlgoContainer_swigregister(IGESToBRep_AlgoContainer)

class IGESToBRep_CurveAndSurface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a tool curveandsurface ready to run, with epsilons set to 1.e-04, mymodetopo to true, the optimization of the continuity to false.

        Returns
        -------
        None
        Creates a tool curveandsurface ready to run.

        Parameters
        ----------
        eps: float
        epsGeom: float
        epsCoeff: float
        mode: bool
        modeapprox: bool
        optimized: bool

        Returns
        -------
        None

        """
        _IGESToBRep.IGESToBRep_CurveAndSurface_swiginit(self, _IGESToBRep.new_IGESToBRep_CurveAndSurface(*args))

    def AddShapeResult(self, *args) -> "void":
        r"""
        Set in 'mymap' the result of the transfer of the entity of the igesentity start ( type vertexlist or edgelist).

        Parameters
        ----------
        start: IGESData_IGESEntity
        result: TopoDS_Shape

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_AddShapeResult(self, *args)

    def GetContinuity(self, *args) -> "Standard_Integer":
        r"""
        Returns the value of 'mycontinuity'.

        Returns
        -------
        int

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_GetContinuity(self, *args)

    def GetEpsCoeff(self, *args) -> "Standard_Real":
        r"""
        Returns the value of 'myepscoeff'.

        Returns
        -------
        float

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_GetEpsCoeff(self, *args)

    def GetEpsGeom(self, *args) -> "Standard_Real":
        r"""
        Returns the value of 'myepsgeom'.

        Returns
        -------
        float

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_GetEpsGeom(self, *args)

    def GetEpsilon(self, *args) -> "Standard_Real":
        r"""
        Returns the value of 'myeps'.

        Returns
        -------
        float

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_GetEpsilon(self, *args)

    def GetMaxTol(self, *args) -> "Standard_Real":
        r"""
        Returns the value of 'mymaxtol'.

        Returns
        -------
        float

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_GetMaxTol(self, *args)

    def GetMinTol(self, *args) -> "Standard_Real":
        r"""
        Returns the value of 'mymintol'.

        Returns
        -------
        float

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_GetMinTol(self, *args)

    def GetModeApprox(self, *args) -> "Standard_Boolean":
        r"""
        Returns the value of 'mymodeapprox'.

        Returns
        -------
        bool

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_GetModeApprox(self, *args)

    def GetModeTransfer(self, *args) -> "Standard_Boolean":
        r"""
        Returns the value of 'mymodeistopo'.

        Returns
        -------
        bool

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_GetModeTransfer(self, *args)

    def GetModel(self, *args) -> "opencascade::handle< IGESData_IGESModel >":
        r"""
        Returns the value of 'mymodel'.

        Returns
        -------
        opencascade::handle<IGESData_IGESModel>

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_GetModel(self, *args)

    def GetOptimized(self, *args) -> "Standard_Boolean":
        r"""
        Returns the value of 'mycontisopti'.

        Returns
        -------
        bool

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_GetOptimized(self, *args)

    def GetShapeResult(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the result of the transfer of the igesentity 'start' contained in 'mymap' . (if hasshaperesult is true).

        Parameters
        ----------
        start: IGESData_IGESEntity

        Returns
        -------
        TopoDS_Shape
        Returns the numth result of the igesentity start (type vertexlist or edgelist) in 'mymap'. (if nbshaperesult is not null).

        Parameters
        ----------
        start: IGESData_IGESEntity
        num: int

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_GetShapeResult(self, *args)

    def GetSurfaceCurve(self, *args) -> "Standard_Integer":
        r"""
        Returns the value of ' mysurfacecurve' 0 = value in file , 2 = kepp 2d and compute 3d 3 = keep 3d and compute 2d.

        Returns
        -------
        int

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_GetSurfaceCurve(self, *args)

    def GetTransferProcess(self, *args) -> "opencascade::handle< Transfer_TransientProcess >":
        r"""
        Returns the value of 'mymsgreg'.

        Returns
        -------
        opencascade::handle<Transfer_TransientProcess>

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_GetTransferProcess(self, *args)

    def GetUVResolution(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_GetUVResolution(self, *args)

    def GetUnitFactor(self, *args) -> "Standard_Real":
        r"""
        Returns the value of ' myunitfactor'.

        Returns
        -------
        float

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_GetUnitFactor(self, *args)

    def HasShapeResult(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if start was already treated and has a result in 'mymap' else returns false.

        Parameters
        ----------
        start: IGESData_IGESEntity

        Returns
        -------
        bool

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_HasShapeResult(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initializes the field of the tool curveandsurface with default creating values.

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_Init(self, *args)

    def NbShapeResult(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of shapes results contained in 'mymap' for the igesentity start ( type vertexlist or edgelist).

        Parameters
        ----------
        start: IGESData_IGESEntity

        Returns
        -------
        int

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_NbShapeResult(self, *args)

    def SendFail(self, *args) -> "void":
        r"""
        Records a new fail message.

        Parameters
        ----------
        start: IGESData_IGESEntity
        amsg: Message_Msg

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_SendFail(self, *args)

    def SendMsg(self, *args) -> "void":
        r"""
        Records a new information message from the definition of a msg (original+value).

        Parameters
        ----------
        start: IGESData_IGESEntity
        amsg: Message_Msg

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_SendMsg(self, *args)

    def SendWarning(self, *args) -> "void":
        r"""
        Records a new warning message.

        Parameters
        ----------
        start: IGESData_IGESEntity
        amsg: Message_Msg

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_SendWarning(self, *args)

    def SetContinuity(self, *args) -> "void":
        r"""
        Changes the value of 'mycontinuity' if continuity = 0 do nothing else if continuity = 1 try c1 if continuity = 2 try c2.

        Parameters
        ----------
        continuity: int

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_SetContinuity(self, *args)

    def SetEpsCoeff(self, *args) -> "void":
        r"""
        Changes the value of 'myepscoeff'.

        Parameters
        ----------
        eps: float

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_SetEpsCoeff(self, *args)

    def SetEpsGeom(self, *args) -> "void":
        r"""
        Changes the value of 'myepsgeom'.

        Parameters
        ----------
        eps: float

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_SetEpsGeom(self, *args)

    def SetEpsilon(self, *args) -> "void":
        r"""
        Changes the value of 'myeps'.

        Parameters
        ----------
        eps: float

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_SetEpsilon(self, *args)

    def SetMaxTol(self, *args) -> "void":
        r"""
        Changes the value of 'mymaxtol'.

        Parameters
        ----------
        maxtol: float

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_SetMaxTol(self, *args)

    def SetMinTol(self, *args) -> "void":
        r"""
        Changes the value of 'mymintol'.

        Parameters
        ----------
        mintol: float

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_SetMinTol(self, *args)

    def SetModeApprox(self, *args) -> "void":
        r"""
        Changes the value of 'mymodeapprox'.

        Parameters
        ----------
        mode: bool

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_SetModeApprox(self, *args)

    def SetModeTransfer(self, *args) -> "void":
        r"""
        Changes the value of 'mymodeistopo'.

        Parameters
        ----------
        mode: bool

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_SetModeTransfer(self, *args)

    def SetModel(self, *args) -> "void":
        r"""
        Set the value of 'mymodel'.

        Parameters
        ----------
        model: IGESData_IGESModel

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_SetModel(self, *args)

    def SetOptimized(self, *args) -> "void":
        r"""
        Changes the value of 'mycontisopti'.

        Parameters
        ----------
        optimized: bool

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_SetOptimized(self, *args)

    def SetShapeResult(self, *args) -> "void":
        r"""
        Set in 'mymap' the result of the transfer of the igesentity 'start'.

        Parameters
        ----------
        start: IGESData_IGESEntity
        result: TopoDS_Shape

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_SetShapeResult(self, *args)

    def SetSurface(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theSurface: Geom_Surface

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_SetSurface(self, *args)

    def SetSurfaceCurve(self, *args) -> "void":
        r"""
        Changes the value of 'mysurfacecurve'.

        Parameters
        ----------
        ival: int

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_SetSurfaceCurve(self, *args)

    def SetTransferProcess(self, *args) -> "void":
        r"""
        Set the value of 'mymsgreg'.

        Parameters
        ----------
        TP: Transfer_TransientProcess

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_SetTransferProcess(self, *args)

    def Surface(self, *args) -> "opencascade::handle< Geom_Surface >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Geom_Surface>

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_Surface(self, *args)

    def TransferCurveAndSurface(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the result of the transfert of any iges curve or surface entity. if the transfer has failed, this member return a nullentity.

        Parameters
        ----------
        start: IGESData_IGESEntity
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_TransferCurveAndSurface(self, *args)

    def TransferGeometry(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the result of the transfert the geometry of any igesentity. if the transfer has failed, this member return a nullentity.

        Parameters
        ----------
        start: IGESData_IGESEntity
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_TransferGeometry(self, *args)

    def UpdateMinMaxTol(self, *args) -> "void":
        r"""
        Sets values of 'mymintol' and 'mymaxtol' as follows mymaxtol = max ('read.maxprecision.val', myepsgeom * myunitfactor) mymintol = precision::confusion() remark: this method is automatically invoked each time the values of 'myepsgeom' or 'myunitfactor' are changed.

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_CurveAndSurface_UpdateMinMaxTol(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IGESToBRep.delete_IGESToBRep_CurveAndSurface

# Register IGESToBRep_CurveAndSurface in _IGESToBRep:
_IGESToBRep.IGESToBRep_CurveAndSurface_swigregister(IGESToBRep_CurveAndSurface)

class IGESToBRep_IGESBoundary(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None
        Empty constructor.

        Parameters
        ----------
        CS: IGESToBRep_CurveAndSurface

        Returns
        -------
        None

        """
        _IGESToBRep.IGESToBRep_IGESBoundary_swiginit(self, _IGESToBRep.new_IGESToBRep_IGESBoundary(*args))

    def Check(self, *args) -> "void":
        r"""
        Checks result of translation of iges boundary entities (types 141, 142 or 508). checks consistency of 2d and 3d representations and keeps only one if they are inconsistent. <result>: result of translation (returned by transfer), <checkclosure>: false for 142 without parent 144 entity, otherwise true, <okcurve3d>, <okcurve2d>: those returned by transfer.

        Parameters
        ----------
        result: bool
        checkclosure: bool
        okCurve3d: bool
        okCurve2d: bool

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_IGESBoundary_Check(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Inits the object with parameters common for all types of iges boundaries. <cs>: object to be used for retrieving translation parameters and sending messages, <entity>: boundary entity to be processed, <face>, <trans>, <ufact>: as for igestobrep_topocurve <filepreference>: preferred representation (2 or 3) given in the iges file.

        Parameters
        ----------
        CS: IGESToBRep_CurveAndSurface
        entity: IGESData_IGESEntity
        face: TopoDS_Face
        trans: gp_Trsf2d
        uFact: float
        filepreference: int

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_IGESBoundary_Init(self, *args)

    def Transfer(self, *args) -> "Standard_Boolean":
        r"""
        Translates 141 and 142 entities. returns true if the curve has been successfully translated, otherwise returns false. <okcurve..>: flags that indicate whether corresponding representation has been successfully translated (must be set to true before first call), <curve3d>: model space curve for 142 and current model space curve for 141, <toreverse3d>: false for 142 and current orientation flag for 141, <curves2d>: 1 parameter space curve for 142 or list of them for current model space curves for 141, <number>: 1 for 142 and rank number of model space curve for 141.

        Parameters
        ----------
        curve3d: IGESData_IGESEntity
        toreverse3d: bool
        curves2d: IGESData_HArray1OfIGESEntity
        number: int

        Returns
        -------
        okCurve: bool
        okCurve3d: bool
        okCurve2d: bool
        Translates 508 entity. returns true if the curve has been successfully translated, otherwise returns false. input object igesboundary must be created and initialized before. <okcurve..>: flags that indicate whether corresponding representation has been successfully translated (must be set to true before first call), <curve3d>: result of translation of current edge, <curves2d>: list of parameter space curves for edge, <toreverse2d>: orientation flag of current edge in respect to its model space curve, <number>: rank number of edge, <lsewd>: returns the result of translation of current edge.

        Parameters
        ----------
        curve3d: ShapeExtend_WireData
        curves2d: IGESData_HArray1OfIGESEntity
        toreverse2d: bool
        number: int
        lsewd: ShapeExtend_WireData

        Returns
        -------
        okCurve: bool
        okCurve3d: bool
        okCurve2d: bool

        """
        return _IGESToBRep.IGESToBRep_IGESBoundary_Transfer(self, *args)

    def WireData(self, *args) -> "opencascade::handle< ShapeExtend_WireData >":
        r"""
        Returns the resulting wire.

        Returns
        -------
        opencascade::handle<ShapeExtend_WireData>

        """
        return _IGESToBRep.IGESToBRep_IGESBoundary_WireData(self, *args)

    def WireData2d(self, *args) -> "opencascade::handle< ShapeExtend_WireData >":
        r"""
        Returns the the wire from 2d curves (edges contain pcurves only).

        Returns
        -------
        opencascade::handle<ShapeExtend_WireData>

        """
        return _IGESToBRep.IGESToBRep_IGESBoundary_WireData2d(self, *args)

    def WireData3d(self, *args) -> "opencascade::handle< ShapeExtend_WireData >":
        r"""
        Returns the wire from 3d curves (edges contain 3d curves and may contain pcurves).

        Returns
        -------
        opencascade::handle<ShapeExtend_WireData>

        """
        return _IGESToBRep.IGESToBRep_IGESBoundary_WireData3d(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_IGESToBRep_IGESBoundary_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IGESToBRep.delete_IGESToBRep_IGESBoundary

# Register IGESToBRep_IGESBoundary in _IGESToBRep:
_IGESToBRep.IGESToBRep_IGESBoundary_swigregister(IGESToBRep_IGESBoundary)

class IGESToBRep_Reader(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a reader.

        Returns
        -------
        None

        """
        _IGESToBRep.IGESToBRep_Reader_swiginit(self, _IGESToBRep.new_IGESToBRep_Reader(*args))

    def Actor(self, *args) -> "opencascade::handle< IGESToBRep_Actor >":
        r"""
        Returns 'theactor'.

        Returns
        -------
        opencascade::handle<IGESToBRep_Actor>

        """
        return _IGESToBRep.IGESToBRep_Reader_Actor(self, *args)

    def Check(self, *args) -> "Standard_Boolean":
        r"""
        Checks the iges file that was loaded into memory. displays error messages in the default message file if withprint is true. returns true if no fail message was found and false if there was at least one fail message.

        Parameters
        ----------
        withprint: bool

        Returns
        -------
        bool

        """
        return _IGESToBRep.IGESToBRep_Reader_Check(self, *args)

    def Clear(self, *args) -> "void":
        r"""
        Clears the results between two translation operations.

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_Reader_Clear(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the last transfer/transferroots was a success.

        Returns
        -------
        bool

        """
        return _IGESToBRep.IGESToBRep_Reader_IsDone(self, *args)

    def LoadFile(self, *args) -> "Standard_Integer":
        r"""
        Loads a model from a file.returns 0 if success. returns 1 if the file could not be opened, returns -1 if an error occurred while the file was being loaded.

        Parameters
        ----------
        filename: char *

        Returns
        -------
        int

        """
        return _IGESToBRep.IGESToBRep_Reader_LoadFile(self, *args)

    def Model(self, *args) -> "opencascade::handle< IGESData_IGESModel >":
        r"""
        Returns the model to be worked on.

        Returns
        -------
        opencascade::handle<IGESData_IGESModel>

        """
        return _IGESToBRep.IGESToBRep_Reader_Model(self, *args)

    def NbShapes(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of shapes produced by the translation.

        Returns
        -------
        int

        """
        return _IGESToBRep.IGESToBRep_Reader_NbShapes(self, *args)

    def OneShape(self, *args) -> "TopoDS_Shape":
        r"""
        Returns all of the results in a single shape which is: - a null shape if there are no results, - a shape if there is one result, - a compound containing the resulting shapes if there are several.

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_Reader_OneShape(self, *args)

    def SetModel(self, *args) -> "void":
        r"""
        Specifies a model to work on also clears the result and done status, sets transientprocess.

        Parameters
        ----------
        model: IGESData_IGESModel

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_Reader_SetModel(self, *args)

    def SetTransientProcess(self, *args) -> "void":
        r"""
        Allows to set an already defined transientprocess (to be called after loadfile or setmodel).

        Parameters
        ----------
        TP: Transfer_TransientProcess

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_Reader_SetTransientProcess(self, *args)

    def Shape(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the num the resulting shape in a translation operation.

        Parameters
        ----------
        num: int,optional
        	default value is 1

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_Reader_Shape(self, *args)

    def Transfer(self, *args) -> "Standard_Boolean":
        r"""
        Transfers an entity given its rank in the model (root or not) returns true if it is recognized as geom-topol. (but it can have failed : see isdone).

        Parameters
        ----------
        num: int
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool

        """
        return _IGESToBRep.IGESToBRep_Reader_Transfer(self, *args)

    def TransferRoots(self, *args) -> "void":
        r"""
        Translates root entities in an iges file. standard_true is the default value and means that only visible root entities are translated. standard_false translates all of the roots (visible and invisible).

        Parameters
        ----------
        onlyvisible: bool,optional
        	default value is Standard_True
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_Reader_TransferRoots(self, *args)

    def TransientProcess(self, *args) -> "opencascade::handle< Transfer_TransientProcess >":
        r"""
        Returns the transientprocess.

        Returns
        -------
        opencascade::handle<Transfer_TransientProcess>

        """
        return _IGESToBRep.IGESToBRep_Reader_TransientProcess(self, *args)

    def UsedTolerance(self, *args) -> "Standard_Real":
        r"""
        Returns the tolerance which has been actually used, converted in millimeters (either that from file or that from session, according the mode).

        Returns
        -------
        float

        """
        return _IGESToBRep.IGESToBRep_Reader_UsedTolerance(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IGESToBRep.delete_IGESToBRep_Reader

# Register IGESToBRep_Reader in _IGESToBRep:
_IGESToBRep.IGESToBRep_Reader_swigregister(IGESToBRep_Reader)

class IGESToBRep_ToolContainer(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _IGESToBRep.IGESToBRep_ToolContainer_swiginit(self, _IGESToBRep.new_IGESToBRep_ToolContainer(*args))

    def IGESBoundary(self, *args) -> "opencascade::handle< IGESToBRep_IGESBoundary >":
        r"""
        Returns igestobrep_igesboundary.

        Returns
        -------
        opencascade::handle<IGESToBRep_IGESBoundary>

        """
        return _IGESToBRep.IGESToBRep_ToolContainer_IGESBoundary(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_IGESToBRep_ToolContainer_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IGESToBRep.delete_IGESToBRep_ToolContainer

# Register IGESToBRep_ToolContainer in _IGESToBRep:
_IGESToBRep.IGESToBRep_ToolContainer_swigregister(IGESToBRep_ToolContainer)

class IGESToBRep_BRepEntity(IGESToBRep_CurveAndSurface):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a tool brepentity ready to run, with epsilons set to 1.e-04, themodetopo to true, the optimization of the continuity to false.

        Returns
        -------
        None
        Creates a tool brepentity ready to run and sets its fields as cs's.

        Parameters
        ----------
        CS: IGESToBRep_CurveAndSurface

        Returns
        -------
        None
        Creates a tool brepentity ready to run.

        Parameters
        ----------
        eps: float
        epsGeom: float
        epsCoeff: float
        mode: bool
        modeapprox: bool
        optimized: bool

        Returns
        -------
        None

        """
        _IGESToBRep.IGESToBRep_BRepEntity_swiginit(self, _IGESToBRep.new_IGESToBRep_BRepEntity(*args))

    def TransferBRepEntity(self, *args) -> "TopoDS_Shape":
        r"""
        Transfer the brepentity' : face, shell or manifoldsolid.

        Parameters
        ----------
        start: IGESData_IGESEntity
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_BRepEntity_TransferBRepEntity(self, *args)

    def TransferEdge(self, *args) -> "TopoDS_Shape":
        r"""
        Transfer the entity number 'index' of the edgelist 'start'.

        Parameters
        ----------
        start: IGESSolid_EdgeList
        index: int

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_BRepEntity_TransferEdge(self, *args)

    def TransferFace(self, *args) -> "TopoDS_Shape":
        r"""
        Transfer the face entity.

        Parameters
        ----------
        start: IGESSolid_Face

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_BRepEntity_TransferFace(self, *args)

    def TransferLoop(self, *args) -> "TopoDS_Shape":
        r"""
        Transfer the loop entity.

        Parameters
        ----------
        start: IGESSolid_Loop
        Face: TopoDS_Face
        trans: gp_Trsf2d
        uFact: float

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_BRepEntity_TransferLoop(self, *args)

    def TransferManifoldSolid(self, *args) -> "TopoDS_Shape":
        r"""
        Transfer the manifoldsolid entity.

        Parameters
        ----------
        start: IGESSolid_ManifoldSolid
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_BRepEntity_TransferManifoldSolid(self, *args)

    def TransferShell(self, *args) -> "TopoDS_Shape":
        r"""
        Transfer the shell entity.

        Parameters
        ----------
        start: IGESSolid_Shell
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_BRepEntity_TransferShell(self, *args)

    def TransferVertex(self, *args) -> "TopoDS_Vertex":
        r"""
        Transfer the entity number 'index' of the vertexlist 'start'.

        Parameters
        ----------
        start: IGESSolid_VertexList
        index: int

        Returns
        -------
        TopoDS_Vertex

        """
        return _IGESToBRep.IGESToBRep_BRepEntity_TransferVertex(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IGESToBRep.delete_IGESToBRep_BRepEntity

# Register IGESToBRep_BRepEntity in _IGESToBRep:
_IGESToBRep.IGESToBRep_BRepEntity_swigregister(IGESToBRep_BRepEntity)

class IGESToBRep_BasicCurve(IGESToBRep_CurveAndSurface):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a tool basiccurve ready to run, with epsilons set to 1.e-04, themodetopo to true, the optimization of the continuity to false.

        Returns
        -------
        None
        Creates a tool basiccurve ready to run and sets its fields as cs's.

        Parameters
        ----------
        CS: IGESToBRep_CurveAndSurface

        Returns
        -------
        None
        Creates a tool basiccurve ready to run.

        Parameters
        ----------
        eps: float
        epsGeom: float
        epsCoeff: float
        mode: bool
        modeapprox: bool
        optimized: bool

        Returns
        -------
        None

        """
        _IGESToBRep.IGESToBRep_BasicCurve_swiginit(self, _IGESToBRep.new_IGESToBRep_BasicCurve(*args))

    def Transfer2dBSplineCurve(self, *args) -> "opencascade::handle< Geom2d_Curve >":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_BSplineCurve

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _IGESToBRep.IGESToBRep_BasicCurve_Transfer2dBSplineCurve(self, *args)

    def Transfer2dBasicCurve(self, *args) -> "opencascade::handle< Geom2d_Curve >":
        r"""
        Transfert a igesentity which answer true to the member : igestobrep::isbasiccurve(igesentity). the igesentity must be a curve uv and its associed trsf must be planar .if this entity could not be converted, this member returns a nullentity.

        Parameters
        ----------
        start: IGESData_IGESEntity

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _IGESToBRep.IGESToBRep_BasicCurve_Transfer2dBasicCurve(self, *args)

    def Transfer2dCircularArc(self, *args) -> "opencascade::handle< Geom2d_Curve >":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_CircularArc

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _IGESToBRep.IGESToBRep_BasicCurve_Transfer2dCircularArc(self, *args)

    def Transfer2dConicArc(self, *args) -> "opencascade::handle< Geom2d_Curve >":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_ConicArc

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _IGESToBRep.IGESToBRep_BasicCurve_Transfer2dConicArc(self, *args)

    def Transfer2dCopiousData(self, *args) -> "opencascade::handle< Geom2d_BSplineCurve >":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_CopiousData

        Returns
        -------
        opencascade::handle<Geom2d_BSplineCurve>

        """
        return _IGESToBRep.IGESToBRep_BasicCurve_Transfer2dCopiousData(self, *args)

    def Transfer2dLine(self, *args) -> "opencascade::handle< Geom2d_Curve >":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_Line

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _IGESToBRep.IGESToBRep_BasicCurve_Transfer2dLine(self, *args)

    def Transfer2dSplineCurve(self, *args) -> "opencascade::handle< Geom2d_BSplineCurve >":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_SplineCurve

        Returns
        -------
        opencascade::handle<Geom2d_BSplineCurve>

        """
        return _IGESToBRep.IGESToBRep_BasicCurve_Transfer2dSplineCurve(self, *args)

    def TransferBSplineCurve(self, *args) -> "opencascade::handle< Geom_Curve >":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_BSplineCurve

        Returns
        -------
        opencascade::handle<Geom_Curve>

        """
        return _IGESToBRep.IGESToBRep_BasicCurve_TransferBSplineCurve(self, *args)

    def TransferBasicCurve(self, *args) -> "opencascade::handle< Geom_Curve >":
        r"""
        Transfert a igesentity which answer true to the member : igestobrep::isbasiccurve(igesentity). if this entity could not be converted, this member returns a nullentity.

        Parameters
        ----------
        start: IGESData_IGESEntity

        Returns
        -------
        opencascade::handle<Geom_Curve>

        """
        return _IGESToBRep.IGESToBRep_BasicCurve_TransferBasicCurve(self, *args)

    def TransferCircularArc(self, *args) -> "opencascade::handle< Geom_Curve >":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_CircularArc

        Returns
        -------
        opencascade::handle<Geom_Curve>

        """
        return _IGESToBRep.IGESToBRep_BasicCurve_TransferCircularArc(self, *args)

    def TransferConicArc(self, *args) -> "opencascade::handle< Geom_Curve >":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_ConicArc

        Returns
        -------
        opencascade::handle<Geom_Curve>

        """
        return _IGESToBRep.IGESToBRep_BasicCurve_TransferConicArc(self, *args)

    def TransferCopiousData(self, *args) -> "opencascade::handle< Geom_BSplineCurve >":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_CopiousData

        Returns
        -------
        opencascade::handle<Geom_BSplineCurve>

        """
        return _IGESToBRep.IGESToBRep_BasicCurve_TransferCopiousData(self, *args)

    def TransferLine(self, *args) -> "opencascade::handle< Geom_Curve >":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_Line

        Returns
        -------
        opencascade::handle<Geom_Curve>

        """
        return _IGESToBRep.IGESToBRep_BasicCurve_TransferLine(self, *args)

    def TransferSplineCurve(self, *args) -> "opencascade::handle< Geom_BSplineCurve >":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_SplineCurve

        Returns
        -------
        opencascade::handle<Geom_BSplineCurve>

        """
        return _IGESToBRep.IGESToBRep_BasicCurve_TransferSplineCurve(self, *args)

    def TransferTransformation(self, *args) -> "opencascade::handle< Geom_Transformation >":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_TransformationMatrix

        Returns
        -------
        opencascade::handle<Geom_Transformation>

        """
        return _IGESToBRep.IGESToBRep_BasicCurve_TransferTransformation(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IGESToBRep.delete_IGESToBRep_BasicCurve

# Register IGESToBRep_BasicCurve in _IGESToBRep:
_IGESToBRep.IGESToBRep_BasicCurve_swigregister(IGESToBRep_BasicCurve)

class IGESToBRep_BasicSurface(IGESToBRep_CurveAndSurface):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a tool basicsurface ready to run, with epsilons set to 1.e-04, themodetopo to true, the optimization of the continuity to false.

        Returns
        -------
        None
        Creates a tool basicsurface ready to run and sets its fields as cs's.

        Parameters
        ----------
        CS: IGESToBRep_CurveAndSurface

        Returns
        -------
        None
        Creates a tool basicsurface ready to run.

        Parameters
        ----------
        eps: float
        epsGeom: float
        epsCoeff: float
        mode: bool
        modeapprox: bool
        optimized: bool

        Returns
        -------
        None

        """
        _IGESToBRep.IGESToBRep_BasicSurface_swiginit(self, _IGESToBRep.new_IGESToBRep_BasicSurface(*args))

    def TransferBSplineSurface(self, *args) -> "opencascade::handle< Geom_BSplineSurface >":
        r"""
        Returns bsplinesurface from geom if the transfer has succeded.

        Parameters
        ----------
        start: IGESGeom_BSplineSurface

        Returns
        -------
        opencascade::handle<Geom_BSplineSurface>

        """
        return _IGESToBRep.IGESToBRep_BasicSurface_TransferBSplineSurface(self, *args)

    def TransferBasicSurface(self, *args) -> "opencascade::handle< Geom_Surface >":
        r"""
        Returns surface from geom if the last transfer has succeded.

        Parameters
        ----------
        start: IGESData_IGESEntity

        Returns
        -------
        opencascade::handle<Geom_Surface>

        """
        return _IGESToBRep.IGESToBRep_BasicSurface_TransferBasicSurface(self, *args)

    def TransferPlaneSurface(self, *args) -> "opencascade::handle< Geom_Plane >":
        r"""
        Returns plane from geom if the transfer has succeded.

        Parameters
        ----------
        start: IGESSolid_PlaneSurface

        Returns
        -------
        opencascade::handle<Geom_Plane>

        """
        return _IGESToBRep.IGESToBRep_BasicSurface_TransferPlaneSurface(self, *args)

    def TransferRigthConicalSurface(self, *args) -> "opencascade::handle< Geom_ConicalSurface >":
        r"""
        Returns conicalsurface from geom if the transfer has succeded.

        Parameters
        ----------
        start: IGESSolid_ConicalSurface

        Returns
        -------
        opencascade::handle<Geom_ConicalSurface>

        """
        return _IGESToBRep.IGESToBRep_BasicSurface_TransferRigthConicalSurface(self, *args)

    def TransferRigthCylindricalSurface(self, *args) -> "opencascade::handle< Geom_CylindricalSurface >":
        r"""
        Returns cylindricalsurface from geom if the transfer has succeded.

        Parameters
        ----------
        start: IGESSolid_CylindricalSurface

        Returns
        -------
        opencascade::handle<Geom_CylindricalSurface>

        """
        return _IGESToBRep.IGESToBRep_BasicSurface_TransferRigthCylindricalSurface(self, *args)

    def TransferSphericalSurface(self, *args) -> "opencascade::handle< Geom_SphericalSurface >":
        r"""
        Returns sphericalsurface from geom if the transfer has succeded.

        Parameters
        ----------
        start: IGESSolid_SphericalSurface

        Returns
        -------
        opencascade::handle<Geom_SphericalSurface>

        """
        return _IGESToBRep.IGESToBRep_BasicSurface_TransferSphericalSurface(self, *args)

    def TransferSplineSurface(self, *args) -> "opencascade::handle< Geom_BSplineSurface >":
        r"""
        Returns bsplinesurface from geom if the transfer has succeded.

        Parameters
        ----------
        start: IGESGeom_SplineSurface

        Returns
        -------
        opencascade::handle<Geom_BSplineSurface>

        """
        return _IGESToBRep.IGESToBRep_BasicSurface_TransferSplineSurface(self, *args)

    def TransferToroidalSurface(self, *args) -> "opencascade::handle< Geom_ToroidalSurface >":
        r"""
        Returns sphericalsurface from geom if the transfer has succeded.

        Parameters
        ----------
        start: IGESSolid_ToroidalSurface

        Returns
        -------
        opencascade::handle<Geom_ToroidalSurface>

        """
        return _IGESToBRep.IGESToBRep_BasicSurface_TransferToroidalSurface(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IGESToBRep.delete_IGESToBRep_BasicSurface

# Register IGESToBRep_BasicSurface in _IGESToBRep:
_IGESToBRep.IGESToBRep_BasicSurface_swigregister(IGESToBRep_BasicSurface)

class IGESToBRep_TopoCurve(IGESToBRep_CurveAndSurface):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a tool topocurve ready to run, with epsilons set to 1.e-04, themodetopo to true, the optimization of the continuity to false.

        Returns
        -------
        None
        Creates a tool topocurve ready to run and sets its fields as cs's.

        Parameters
        ----------
        CS: IGESToBRep_CurveAndSurface

        Returns
        -------
        None
        Creates a tool topocurve ready to run and sets its fields as cs's.

        Parameters
        ----------
        CS: IGESToBRep_TopoCurve

        Returns
        -------
        None
        Creates a tool topocurve ready to run.

        Parameters
        ----------
        eps: float
        epsGeom: float
        epsCoeff: float
        mode: bool
        modeapprox: bool
        optimized: bool

        Returns
        -------
        None

        """
        _IGESToBRep.IGESToBRep_TopoCurve_swiginit(self, _IGESToBRep.new_IGESToBRep_TopoCurve(*args))

    def Approx2dBSplineCurve(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        start: Geom2d_BSplineCurve

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_Approx2dBSplineCurve(self, *args)

    def ApproxBSplineCurve(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        start: Geom_BSplineCurve

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_ApproxBSplineCurve(self, *args)

    def BadCase(self, *args) -> "Standard_Boolean":
        r"""
        Returns thebadcase flag.

        Returns
        -------
        bool

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_BadCase(self, *args)

    def Curve(self, *args) -> "opencascade::handle< Geom_Curve >":
        r"""
        Returns a curve given its rank, by default the first one (null curvee if out of range) in 'thecurves'.

        Parameters
        ----------
        num: int,optional
        	default value is 1

        Returns
        -------
        opencascade::handle<Geom_Curve>

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_Curve(self, *args)

    def Curve2d(self, *args) -> "opencascade::handle< Geom2d_Curve >":
        r"""
        Returns a curve given its rank, by default the first one (null curvee if out of range) in 'thecurves2d'.

        Parameters
        ----------
        num: int,optional
        	default value is 1

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_Curve2d(self, *args)

    def NbCurves(self, *args) -> "Standard_Integer":
        r"""
        Returns the count of curves in 'thecurves'.

        Returns
        -------
        int

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_NbCurves(self, *args)

    def NbCurves2d(self, *args) -> "Standard_Integer":
        r"""
        Returns the count of curves in 'thecurves2d'.

        Returns
        -------
        int

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_NbCurves2d(self, *args)

    def SetBadCase(self, *args) -> "void":
        r"""
        Sets thebadcase flag.

        Parameters
        ----------
        value: bool

        Returns
        -------
        None

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_SetBadCase(self, *args)

    def Transfer2dCompositeCurve(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_CompositeCurve
        face: TopoDS_Face
        trans: gp_Trsf2d
        uFact: float

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_Transfer2dCompositeCurve(self, *args)

    def Transfer2dOffsetCurve(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_OffsetCurve
        face: TopoDS_Face
        trans: gp_Trsf2d
        uFact: float

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_Transfer2dOffsetCurve(self, *args)

    def Transfer2dPoint(self, *args) -> "TopoDS_Vertex":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_Point

        Returns
        -------
        TopoDS_Vertex

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_Transfer2dPoint(self, *args)

    def Transfer2dTopoBasicCurve(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESData_IGESEntity
        face: TopoDS_Face
        trans: gp_Trsf2d
        uFact: float

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_Transfer2dTopoBasicCurve(self, *args)

    def Transfer2dTopoCurve(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESData_IGESEntity
        face: TopoDS_Face
        trans: gp_Trsf2d
        uFact: float

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_Transfer2dTopoCurve(self, *args)

    def TransferBoundary(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_Boundary

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_TransferBoundary(self, *args)

    def TransferBoundaryOnFace(self, *args) -> "TopoDS_Shape":
        r"""
        Transfers a boundary directly on a face to trim it.

        Parameters
        ----------
        face: TopoDS_Face
        start: IGESGeom_Boundary
        trans: gp_Trsf2d
        uFact: float

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_TransferBoundaryOnFace(self, *args)

    def TransferCompositeCurve(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_CompositeCurve

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_TransferCompositeCurve(self, *args)

    def TransferCurveOnFace(self, *args) -> "TopoDS_Shape":
        r"""
        Transfers a curveonsurface directly on a face to trim it. the curveonsurface have to be defined outer or inner.

        Parameters
        ----------
        face: TopoDS_Face
        start: IGESGeom_CurveOnSurface
        trans: gp_Trsf2d
        uFact: float
        IsCurv: bool

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_TransferCurveOnFace(self, *args)

    def TransferCurveOnSurface(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_CurveOnSurface

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_TransferCurveOnSurface(self, *args)

    def TransferOffsetCurve(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_OffsetCurve

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_TransferOffsetCurve(self, *args)

    def TransferPoint(self, *args) -> "TopoDS_Vertex":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_Point

        Returns
        -------
        TopoDS_Vertex

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_TransferPoint(self, *args)

    def TransferTopoBasicCurve(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESData_IGESEntity

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_TransferTopoBasicCurve(self, *args)

    def TransferTopoCurve(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESData_IGESEntity

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoCurve_TransferTopoCurve(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IGESToBRep.delete_IGESToBRep_TopoCurve

# Register IGESToBRep_TopoCurve in _IGESToBRep:
_IGESToBRep.IGESToBRep_TopoCurve_swigregister(IGESToBRep_TopoCurve)

class IGESToBRep_TopoSurface(IGESToBRep_CurveAndSurface):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a tool toposurface ready to run, with epsilons set to 1.e-04, themodetopo to true, the optimization of the continuity to false.

        Returns
        -------
        None
        Creates a tool toposurface ready to run and sets its fields as cs's.

        Parameters
        ----------
        CS: IGESToBRep_CurveAndSurface

        Returns
        -------
        None
        Creates a tool toposurface ready to run.

        Parameters
        ----------
        eps: float
        epsGeom: float
        epsCoeff: float
        mode: bool
        modeapprox: bool
        optimized: bool

        Returns
        -------
        None

        """
        _IGESToBRep.IGESToBRep_TopoSurface_swiginit(self, _IGESToBRep.new_IGESToBRep_TopoSurface(*args))

    def ParamSurface(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESData_IGESEntity
        trans: gp_Trsf2d

        Returns
        -------
        uFact: float

        """
        return _IGESToBRep.IGESToBRep_TopoSurface_ParamSurface(self, *args)

    def TransferBoundedSurface(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_BoundedSurface

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoSurface_TransferBoundedSurface(self, *args)

    def TransferOffsetSurface(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_OffsetSurface

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoSurface_TransferOffsetSurface(self, *args)

    def TransferPerforate(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESBasic_SingleParent

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoSurface_TransferPerforate(self, *args)

    def TransferPlane(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_Plane

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoSurface_TransferPlane(self, *args)

    def TransferRuledSurface(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_RuledSurface

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoSurface_TransferRuledSurface(self, *args)

    def TransferSurfaceOfRevolution(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_SurfaceOfRevolution

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoSurface_TransferSurfaceOfRevolution(self, *args)

    def TransferTabulatedCylinder(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_TabulatedCylinder

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoSurface_TransferTabulatedCylinder(self, *args)

    def TransferTopoBasicSurface(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESData_IGESEntity

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoSurface_TransferTopoBasicSurface(self, *args)

    def TransferTopoSurface(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESData_IGESEntity

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoSurface_TransferTopoSurface(self, *args)

    def TransferTrimmedSurface(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        start: IGESGeom_TrimmedSurface

        Returns
        -------
        TopoDS_Shape

        """
        return _IGESToBRep.IGESToBRep_TopoSurface_TransferTrimmedSurface(self, *args)

    __repr__ = _dumps_object

    @methodnotwrapped
    def TransferPlaneSurface(self):
    	pass

    __swig_destroy__ = _IGESToBRep.delete_IGESToBRep_TopoSurface

# Register IGESToBRep_TopoSurface in _IGESToBRep:
_IGESToBRep.IGESToBRep_TopoSurface_swigregister(IGESToBRep_TopoSurface)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.StepData import *
from OCC.Core.IFSelect import *
from OCC.Core.Interface import *
from OCC.Core.TCollection import *


class stepedit:
	@staticmethod
	def NewModel() -> StepData_StepModel: ...
	@staticmethod
	def NewSelectPlacedItem() -> IFSelect_SelectSignature: ...
	@staticmethod
	def NewSelectSDR() -> IFSelect_SelectSignature: ...
	@staticmethod
	def NewSelectShapeRepr() -> IFSelect_SelectSignature: ...
	@staticmethod
	def Protocol() -> Interface_Protocol: ...
	@staticmethod
	def SignType() -> IFSelect_Signature: ...

class STEPEdit_EditContext(IFSelect_Editor):
	def __init__(self) -> None: ...
	def Apply(self, form: IFSelect_EditForm, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...
	def Label(self) -> TCollection_AsciiString: ...
	def Load(self, form: IFSelect_EditForm, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...
	def Recognize(self, form: IFSelect_EditForm) -> bool: ...
	def StringValue(self, form: IFSelect_EditForm, num: int) -> TCollection_HAsciiString: ...

class STEPEdit_EditSDR(IFSelect_Editor):
	def __init__(self) -> None: ...
	def Apply(self, form: IFSelect_EditForm, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...
	def Label(self) -> TCollection_AsciiString: ...
	def Load(self, form: IFSelect_EditForm, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...
	def Recognize(self, form: IFSelect_EditForm) -> bool: ...
	def StringValue(self, form: IFSelect_EditForm, num: int) -> TCollection_HAsciiString: ...

# harray1 classes
# harray2 classes
# hsequence classes

stepedit_NewModel = stepedit.NewModel
stepedit_NewSelectPlacedItem = stepedit.NewSelectPlacedItem
stepedit_NewSelectSDR = stepedit.NewSelectSDR
stepedit_NewSelectShapeRepr = stepedit.NewSelectShapeRepr
stepedit_Protocol = stepedit.Protocol
stepedit_SignType = stepedit.SignType



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Geom import *
from OCC.Core.gp import *
from OCC.Core.GeomAbs import *
from OCC.Core.TColStd import *
from OCC.Core.TopAbs import *
from OCC.Core.Adaptor2d import *
from OCC.Core.math import *

Adaptor3d_CurveOnSurfacePtr = NewType('Adaptor3d_CurveOnSurfacePtr', Adaptor3d_CurveOnSurface)
Adaptor3d_CurvePtr = NewType('Adaptor3d_CurvePtr', Adaptor3d_Curve)
Adaptor3d_SurfacePtr = NewType('Adaptor3d_SurfacePtr', Adaptor3d_Surface)

class Adaptor3d_Curve:
	def BSpline(self) -> Geom_BSplineCurve: ...
	def Bezier(self) -> Geom_BezierCurve: ...
	def Circle(self) -> gp_Circ: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, P: gp_Pnt, V: gp_Vec) -> None: ...
	def D2(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D3(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec: ...
	def Degree(self) -> int: ...
	def Ellipse(self) -> gp_Elips: ...
	def FirstParameter(self) -> float: ...
	def GetType(self) -> GeomAbs_CurveType: ...
	def Hyperbola(self) -> gp_Hypr: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def IsRational(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def Line(self) -> gp_Lin: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbKnots(self) -> int: ...
	def NbPoles(self) -> int: ...
	def OffsetCurve(self) -> Geom_OffsetCurve: ...
	def Parabola(self) -> gp_Parab: ...
	def Period(self) -> float: ...
	def Resolution(self, R3d: float) -> float: ...
	def Trim(self, First: float, Last: float, Tol: float) -> Adaptor3d_HCurve: ...
	def Value(self, U: float) -> gp_Pnt: ...

class Adaptor3d_HCurve(Standard_Transient):
	def BSpline(self) -> Geom_BSplineCurve: ...
	def Bezier(self) -> Geom_BezierCurve: ...
	def Circle(self) -> gp_Circ: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Curve(self) -> Adaptor3d_Curve: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, P: gp_Pnt, V: gp_Vec) -> None: ...
	def D2(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D3(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec: ...
	def Degree(self) -> int: ...
	def Ellipse(self) -> gp_Elips: ...
	def FirstParameter(self) -> float: ...
	def GetCurve(self) -> Adaptor3d_Curve: ...
	def GetType(self) -> GeomAbs_CurveType: ...
	def Hyperbola(self) -> gp_Hypr: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def IsRational(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def Line(self) -> gp_Lin: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbKnots(self) -> int: ...
	def NbPoles(self) -> int: ...
	def OffsetCurve(self) -> Geom_OffsetCurve: ...
	def Parabola(self) -> gp_Parab: ...
	def Period(self) -> float: ...
	def Resolution(self, R3d: float) -> float: ...
	def Trim(self, First: float, Last: float, Tol: float) -> Adaptor3d_HCurve: ...
	def Value(self, U: float) -> gp_Pnt: ...

class Adaptor3d_HSurface(Standard_Transient):
	def AxeOfRevolution(self) -> gp_Ax1: ...
	def BSpline(self) -> Geom_BSplineSurface: ...
	def BasisCurve(self) -> Adaptor3d_HCurve: ...
	def BasisSurface(self) -> Adaptor3d_HSurface: ...
	def Bezier(self) -> Geom_BezierSurface: ...
	def Cone(self) -> gp_Cone: ...
	def Cylinder(self) -> gp_Cylinder: ...
	def D0(self, U: float, V: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec) -> None: ...
	def D2(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec) -> None: ...
	def D3(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec, D3U: gp_Vec, D3V: gp_Vec, D3UUV: gp_Vec, D3UVV: gp_Vec) -> None: ...
	def DN(self, U: float, V: float, Nu: int, Nv: int) -> gp_Vec: ...
	def Direction(self) -> gp_Dir: ...
	def FirstUParameter(self) -> float: ...
	def FirstVParameter(self) -> float: ...
	def GetType(self) -> GeomAbs_SurfaceType: ...
	def IsUClosed(self) -> bool: ...
	def IsUPeriodic(self) -> bool: ...
	def IsURational(self) -> bool: ...
	def IsVClosed(self) -> bool: ...
	def IsVPeriodic(self) -> bool: ...
	def IsVRational(self) -> bool: ...
	def LastUParameter(self) -> float: ...
	def LastVParameter(self) -> float: ...
	def NbUIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbUKnots(self) -> int: ...
	def NbUPoles(self) -> int: ...
	def NbVIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbVKnots(self) -> int: ...
	def NbVPoles(self) -> int: ...
	def OffsetValue(self) -> float: ...
	def Plane(self) -> gp_Pln: ...
	def Sphere(self) -> gp_Sphere: ...
	def Surface(self) -> Adaptor3d_Surface: ...
	def Torus(self) -> gp_Torus: ...
	def UContinuity(self) -> GeomAbs_Shape: ...
	def UDegree(self) -> int: ...
	def UIntervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def UPeriod(self) -> float: ...
	def UResolution(self, R3d: float) -> float: ...
	def UTrim(self, First: float, Last: float, Tol: float) -> Adaptor3d_HSurface: ...
	def VContinuity(self) -> GeomAbs_Shape: ...
	def VDegree(self) -> int: ...
	def VIntervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def VPeriod(self) -> float: ...
	def VResolution(self, R3d: float) -> float: ...
	def VTrim(self, First: float, Last: float, Tol: float) -> Adaptor3d_HSurface: ...
	def Value(self, U: float, V: float) -> gp_Pnt: ...

class Adaptor3d_HSurfaceTool:
	@staticmethod
	def AxeOfRevolution(S: Adaptor3d_HSurface) -> gp_Ax1: ...
	@staticmethod
	def BSpline(S: Adaptor3d_HSurface) -> Geom_BSplineSurface: ...
	@staticmethod
	def BasisCurve(S: Adaptor3d_HSurface) -> Adaptor3d_HCurve: ...
	@staticmethod
	def BasisSurface(S: Adaptor3d_HSurface) -> Adaptor3d_HSurface: ...
	@staticmethod
	def Bezier(S: Adaptor3d_HSurface) -> Geom_BezierSurface: ...
	@staticmethod
	def Cone(S: Adaptor3d_HSurface) -> gp_Cone: ...
	@staticmethod
	def Cylinder(S: Adaptor3d_HSurface) -> gp_Cylinder: ...
	@staticmethod
	def D0(S: Adaptor3d_HSurface, u: float, v: float, P: gp_Pnt) -> None: ...
	@staticmethod
	def D1(S: Adaptor3d_HSurface, u: float, v: float, P: gp_Pnt, D1u: gp_Vec, D1v: gp_Vec) -> None: ...
	@staticmethod
	def D2(S: Adaptor3d_HSurface, u: float, v: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec) -> None: ...
	@staticmethod
	def D3(S: Adaptor3d_HSurface, u: float, v: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec, D3U: gp_Vec, D3V: gp_Vec, D3UUV: gp_Vec, D3UVV: gp_Vec) -> None: ...
	@staticmethod
	def DN(S: Adaptor3d_HSurface, u: float, v: float, Nu: int, Nv: int) -> gp_Vec: ...
	@staticmethod
	def Direction(S: Adaptor3d_HSurface) -> gp_Dir: ...
	@staticmethod
	def FirstUParameter(S: Adaptor3d_HSurface) -> float: ...
	@staticmethod
	def FirstVParameter(S: Adaptor3d_HSurface) -> float: ...
	@staticmethod
	def GetType(S: Adaptor3d_HSurface) -> GeomAbs_SurfaceType: ...
	@staticmethod
	def IsUClosed(S: Adaptor3d_HSurface) -> bool: ...
	@staticmethod
	def IsUPeriodic(S: Adaptor3d_HSurface) -> bool: ...
	@staticmethod
	def IsVClosed(S: Adaptor3d_HSurface) -> bool: ...
	@staticmethod
	def IsVPeriodic(S: Adaptor3d_HSurface) -> bool: ...
	@staticmethod
	def LastUParameter(S: Adaptor3d_HSurface) -> float: ...
	@staticmethod
	def LastVParameter(S: Adaptor3d_HSurface) -> float: ...
	@overload
	@staticmethod
	def NbSamplesU(S: Adaptor3d_HSurface) -> int: ...
	@overload
	@staticmethod
	def NbSamplesU(S: Adaptor3d_HSurface, u1: float, u2: float) -> int: ...
	@overload
	@staticmethod
	def NbSamplesV(S: Adaptor3d_HSurface) -> int: ...
	@overload
	@staticmethod
	def NbSamplesV(S: Adaptor3d_HSurface, v1: float, v2: float) -> int: ...
	@staticmethod
	def NbUIntervals(S: Adaptor3d_HSurface, Sh: GeomAbs_Shape) -> int: ...
	@staticmethod
	def NbVIntervals(S: Adaptor3d_HSurface, Sh: GeomAbs_Shape) -> int: ...
	@staticmethod
	def OffsetValue(S: Adaptor3d_HSurface) -> float: ...
	@staticmethod
	def Plane(S: Adaptor3d_HSurface) -> gp_Pln: ...
	@staticmethod
	def Sphere(S: Adaptor3d_HSurface) -> gp_Sphere: ...
	@staticmethod
	def Torus(S: Adaptor3d_HSurface) -> gp_Torus: ...
	@staticmethod
	def UIntervals(S: Adaptor3d_HSurface, T: TColStd_Array1OfReal, Sh: GeomAbs_Shape) -> None: ...
	@staticmethod
	def UPeriod(S: Adaptor3d_HSurface) -> float: ...
	@staticmethod
	def UResolution(S: Adaptor3d_HSurface, R3d: float) -> float: ...
	@staticmethod
	def UTrim(S: Adaptor3d_HSurface, First: float, Last: float, Tol: float) -> Adaptor3d_HSurface: ...
	@staticmethod
	def VIntervals(S: Adaptor3d_HSurface, T: TColStd_Array1OfReal, Sh: GeomAbs_Shape) -> None: ...
	@staticmethod
	def VPeriod(S: Adaptor3d_HSurface) -> float: ...
	@staticmethod
	def VResolution(S: Adaptor3d_HSurface, R3d: float) -> float: ...
	@staticmethod
	def VTrim(S: Adaptor3d_HSurface, First: float, Last: float, Tol: float) -> Adaptor3d_HSurface: ...
	@staticmethod
	def Value(S: Adaptor3d_HSurface, u: float, v: float) -> gp_Pnt: ...

class Adaptor3d_HVertex(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt2d, Ori: TopAbs_Orientation, Resolution: float) -> None: ...
	def IsSame(self, Other: Adaptor3d_HVertex) -> bool: ...
	def Orientation(self) -> TopAbs_Orientation: ...
	def Parameter(self, C: Adaptor2d_HCurve2d) -> float: ...
	def Resolution(self, C: Adaptor2d_HCurve2d) -> float: ...
	def Value(self) -> gp_Pnt2d: ...

class Adaptor3d_InterFunc(math_FunctionWithDerivative):
	def __init__(self, C: Adaptor2d_HCurve2d, FixVal: float, Fix: int) -> None: ...
	def Derivative(self, X: float) -> Tuple[bool, float]: ...
	def Value(self, X: float) -> Tuple[bool, float]: ...
	def Values(self, X: float) -> Tuple[bool, float, float]: ...

class Adaptor3d_Surface:
	def AxeOfRevolution(self) -> gp_Ax1: ...
	def BSpline(self) -> Geom_BSplineSurface: ...
	def BasisCurve(self) -> Adaptor3d_HCurve: ...
	def BasisSurface(self) -> Adaptor3d_HSurface: ...
	def Bezier(self) -> Geom_BezierSurface: ...
	def Cone(self) -> gp_Cone: ...
	def Cylinder(self) -> gp_Cylinder: ...
	def D0(self, U: float, V: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec) -> None: ...
	def D2(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec) -> None: ...
	def D3(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec, D3U: gp_Vec, D3V: gp_Vec, D3UUV: gp_Vec, D3UVV: gp_Vec) -> None: ...
	def DN(self, U: float, V: float, Nu: int, Nv: int) -> gp_Vec: ...
	def Direction(self) -> gp_Dir: ...
	def FirstUParameter(self) -> float: ...
	def FirstVParameter(self) -> float: ...
	def GetType(self) -> GeomAbs_SurfaceType: ...
	def IsUClosed(self) -> bool: ...
	def IsUPeriodic(self) -> bool: ...
	def IsURational(self) -> bool: ...
	def IsVClosed(self) -> bool: ...
	def IsVPeriodic(self) -> bool: ...
	def IsVRational(self) -> bool: ...
	def LastUParameter(self) -> float: ...
	def LastVParameter(self) -> float: ...
	def NbUIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbUKnots(self) -> int: ...
	def NbUPoles(self) -> int: ...
	def NbVIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbVKnots(self) -> int: ...
	def NbVPoles(self) -> int: ...
	def OffsetValue(self) -> float: ...
	def Plane(self) -> gp_Pln: ...
	def Sphere(self) -> gp_Sphere: ...
	def Torus(self) -> gp_Torus: ...
	def UContinuity(self) -> GeomAbs_Shape: ...
	def UDegree(self) -> int: ...
	def UIntervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def UPeriod(self) -> float: ...
	def UResolution(self, R3d: float) -> float: ...
	def UTrim(self, First: float, Last: float, Tol: float) -> Adaptor3d_HSurface: ...
	def VContinuity(self) -> GeomAbs_Shape: ...
	def VDegree(self) -> int: ...
	def VIntervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def VPeriod(self) -> float: ...
	def VResolution(self, R3d: float) -> float: ...
	def VTrim(self, First: float, Last: float, Tol: float) -> Adaptor3d_HSurface: ...
	def Value(self, U: float, V: float) -> gp_Pnt: ...

class Adaptor3d_TopolTool(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Surface: Adaptor3d_HSurface) -> None: ...
	def BSplSamplePnts(self, theDefl: float, theNUmin: int, theNVmin: int) -> None: ...
	def Classify(self, P: gp_Pnt2d, Tol: float, ReacdreOnPeriodic: Optional[bool] = True) -> TopAbs_State: ...
	def ComputeSamplePoints(self) -> None: ...
	def DomainIsInfinite(self) -> bool: ...
	def Edge(self) -> None: ...
	def Has3d(self) -> bool: ...
	def Identical(self, V1: Adaptor3d_HVertex, V2: Adaptor3d_HVertex) -> bool: ...
	def Init(self) -> None: ...
	def InitVertexIterator(self) -> None: ...
	@overload
	def Initialize(self) -> None: ...
	@overload
	def Initialize(self, S: Adaptor3d_HSurface) -> None: ...
	@overload
	def Initialize(self, Curve: Adaptor2d_HCurve2d) -> None: ...
	def IsThePointOn(self, P: gp_Pnt2d, Tol: float, ReacdreOnPeriodic: Optional[bool] = True) -> bool: ...
	def IsUniformSampling(self) -> bool: ...
	def More(self) -> bool: ...
	def MoreVertex(self) -> bool: ...
	def NbSamples(self) -> int: ...
	def NbSamplesU(self) -> int: ...
	def NbSamplesV(self) -> int: ...
	def Next(self) -> None: ...
	def NextVertex(self) -> None: ...
	@overload
	def Orientation(self, C: Adaptor2d_HCurve2d) -> TopAbs_Orientation: ...
	@overload
	def Orientation(self, V: Adaptor3d_HVertex) -> TopAbs_Orientation: ...
	def Pnt(self, V: Adaptor3d_HVertex) -> gp_Pnt: ...
	def SamplePnts(self, theDefl: float, theNUmin: int, theNVmin: int) -> None: ...
	def SamplePoint(self, Index: int, P2d: gp_Pnt2d, P3d: gp_Pnt) -> None: ...
	@overload
	def Tol3d(self, C: Adaptor2d_HCurve2d) -> float: ...
	@overload
	def Tol3d(self, V: Adaptor3d_HVertex) -> float: ...
	def UParameters(self, theArray: TColStd_Array1OfReal) -> None: ...
	def VParameters(self, theArray: TColStd_Array1OfReal) -> None: ...
	def Value(self) -> Adaptor2d_HCurve2d: ...
	def Vertex(self) -> Adaptor3d_HVertex: ...

class Adaptor3d_CurveOnSurface(Adaptor3d_Curve):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: Adaptor3d_HSurface) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_HCurve2d, S: Adaptor3d_HSurface) -> None: ...
	def BSpline(self) -> Geom_BSplineCurve: ...
	def Bezier(self) -> Geom_BezierCurve: ...
	def ChangeCurve(self) -> Adaptor2d_HCurve2d: ...
	def ChangeSurface(self) -> Adaptor3d_HSurface: ...
	def Circle(self) -> gp_Circ: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, P: gp_Pnt, V: gp_Vec) -> None: ...
	def D2(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D3(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec: ...
	def Degree(self) -> int: ...
	def Ellipse(self) -> gp_Elips: ...
	def FirstParameter(self) -> float: ...
	def GetCurve(self) -> Adaptor2d_HCurve2d: ...
	def GetSurface(self) -> Adaptor3d_HSurface: ...
	def GetType(self) -> GeomAbs_CurveType: ...
	def Hyperbola(self) -> gp_Hypr: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def IsRational(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def Line(self) -> gp_Lin: ...
	@overload
	def Load(self, S: Adaptor3d_HSurface) -> None: ...
	@overload
	def Load(self, C: Adaptor2d_HCurve2d) -> None: ...
	@overload
	def Load(self, C: Adaptor2d_HCurve2d, S: Adaptor3d_HSurface) -> None: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbKnots(self) -> int: ...
	def NbPoles(self) -> int: ...
	def Parabola(self) -> gp_Parab: ...
	def Period(self) -> float: ...
	def Resolution(self, R3d: float) -> float: ...
	def Trim(self, First: float, Last: float, Tol: float) -> Adaptor3d_HCurve: ...
	def Value(self, U: float) -> gp_Pnt: ...

class Adaptor3d_HCurveOnSurface(Adaptor3d_HCurve):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_CurveOnSurface) -> None: ...
	def ChangeCurve(self) -> Adaptor3d_CurveOnSurface: ...
	def Curve(self) -> Adaptor3d_Curve: ...
	def GetCurve(self) -> Adaptor3d_Curve: ...
	def Set(self, C: Adaptor3d_CurveOnSurface) -> None: ...

class Adaptor3d_HIsoCurve(Adaptor3d_HCurve):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_IsoCurve) -> None: ...
	def ChangeCurve(self) -> Adaptor3d_IsoCurve: ...
	def Curve(self) -> Adaptor3d_Curve: ...
	def GetCurve(self) -> Adaptor3d_Curve: ...
	def Set(self, C: Adaptor3d_IsoCurve) -> None: ...

class Adaptor3d_IsoCurve(Adaptor3d_Curve):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: Adaptor3d_HSurface) -> None: ...
	@overload
	def __init__(self, S: Adaptor3d_HSurface, Iso: GeomAbs_IsoType, Param: float) -> None: ...
	@overload
	def __init__(self, S: Adaptor3d_HSurface, Iso: GeomAbs_IsoType, Param: float, WFirst: float, WLast: float) -> None: ...
	def BSpline(self) -> Geom_BSplineCurve: ...
	def Bezier(self) -> Geom_BezierCurve: ...
	def Circle(self) -> gp_Circ: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, P: gp_Pnt, V: gp_Vec) -> None: ...
	def D2(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D3(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec: ...
	def Degree(self) -> int: ...
	def Ellipse(self) -> gp_Elips: ...
	def FirstParameter(self) -> float: ...
	def GetType(self) -> GeomAbs_CurveType: ...
	def Hyperbola(self) -> gp_Hypr: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def IsRational(self) -> bool: ...
	def Iso(self) -> GeomAbs_IsoType: ...
	def LastParameter(self) -> float: ...
	def Line(self) -> gp_Lin: ...
	@overload
	def Load(self, S: Adaptor3d_HSurface) -> None: ...
	@overload
	def Load(self, Iso: GeomAbs_IsoType, Param: float) -> None: ...
	@overload
	def Load(self, Iso: GeomAbs_IsoType, Param: float, WFirst: float, WLast: float) -> None: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbKnots(self) -> int: ...
	def NbPoles(self) -> int: ...
	def Parabola(self) -> gp_Parab: ...
	def Parameter(self) -> float: ...
	def Period(self) -> float: ...
	def Resolution(self, R3d: float) -> float: ...
	def Surface(self) -> Adaptor3d_HSurface: ...
	def Trim(self, First: float, Last: float, Tol: float) -> Adaptor3d_HCurve: ...
	def Value(self, U: float) -> gp_Pnt: ...

# harray1 classes
# harray2 classes
# hsequence classes

Adaptor3d_HSurfaceTool_AxeOfRevolution = Adaptor3d_HSurfaceTool.AxeOfRevolution
Adaptor3d_HSurfaceTool_BSpline = Adaptor3d_HSurfaceTool.BSpline
Adaptor3d_HSurfaceTool_BasisCurve = Adaptor3d_HSurfaceTool.BasisCurve
Adaptor3d_HSurfaceTool_BasisSurface = Adaptor3d_HSurfaceTool.BasisSurface
Adaptor3d_HSurfaceTool_Bezier = Adaptor3d_HSurfaceTool.Bezier
Adaptor3d_HSurfaceTool_Cone = Adaptor3d_HSurfaceTool.Cone
Adaptor3d_HSurfaceTool_Cylinder = Adaptor3d_HSurfaceTool.Cylinder
Adaptor3d_HSurfaceTool_D0 = Adaptor3d_HSurfaceTool.D0
Adaptor3d_HSurfaceTool_D1 = Adaptor3d_HSurfaceTool.D1
Adaptor3d_HSurfaceTool_D2 = Adaptor3d_HSurfaceTool.D2
Adaptor3d_HSurfaceTool_D3 = Adaptor3d_HSurfaceTool.D3
Adaptor3d_HSurfaceTool_DN = Adaptor3d_HSurfaceTool.DN
Adaptor3d_HSurfaceTool_Direction = Adaptor3d_HSurfaceTool.Direction
Adaptor3d_HSurfaceTool_FirstUParameter = Adaptor3d_HSurfaceTool.FirstUParameter
Adaptor3d_HSurfaceTool_FirstVParameter = Adaptor3d_HSurfaceTool.FirstVParameter
Adaptor3d_HSurfaceTool_GetType = Adaptor3d_HSurfaceTool.GetType
Adaptor3d_HSurfaceTool_IsUClosed = Adaptor3d_HSurfaceTool.IsUClosed
Adaptor3d_HSurfaceTool_IsUPeriodic = Adaptor3d_HSurfaceTool.IsUPeriodic
Adaptor3d_HSurfaceTool_IsVClosed = Adaptor3d_HSurfaceTool.IsVClosed
Adaptor3d_HSurfaceTool_IsVPeriodic = Adaptor3d_HSurfaceTool.IsVPeriodic
Adaptor3d_HSurfaceTool_LastUParameter = Adaptor3d_HSurfaceTool.LastUParameter
Adaptor3d_HSurfaceTool_LastVParameter = Adaptor3d_HSurfaceTool.LastVParameter
Adaptor3d_HSurfaceTool_NbSamplesU = Adaptor3d_HSurfaceTool.NbSamplesU
Adaptor3d_HSurfaceTool_NbSamplesU = Adaptor3d_HSurfaceTool.NbSamplesU
Adaptor3d_HSurfaceTool_NbSamplesV = Adaptor3d_HSurfaceTool.NbSamplesV
Adaptor3d_HSurfaceTool_NbSamplesV = Adaptor3d_HSurfaceTool.NbSamplesV
Adaptor3d_HSurfaceTool_NbUIntervals = Adaptor3d_HSurfaceTool.NbUIntervals
Adaptor3d_HSurfaceTool_NbVIntervals = Adaptor3d_HSurfaceTool.NbVIntervals
Adaptor3d_HSurfaceTool_OffsetValue = Adaptor3d_HSurfaceTool.OffsetValue
Adaptor3d_HSurfaceTool_Plane = Adaptor3d_HSurfaceTool.Plane
Adaptor3d_HSurfaceTool_Sphere = Adaptor3d_HSurfaceTool.Sphere
Adaptor3d_HSurfaceTool_Torus = Adaptor3d_HSurfaceTool.Torus
Adaptor3d_HSurfaceTool_UIntervals = Adaptor3d_HSurfaceTool.UIntervals
Adaptor3d_HSurfaceTool_UPeriod = Adaptor3d_HSurfaceTool.UPeriod
Adaptor3d_HSurfaceTool_UResolution = Adaptor3d_HSurfaceTool.UResolution
Adaptor3d_HSurfaceTool_UTrim = Adaptor3d_HSurfaceTool.UTrim
Adaptor3d_HSurfaceTool_VIntervals = Adaptor3d_HSurfaceTool.VIntervals
Adaptor3d_HSurfaceTool_VPeriod = Adaptor3d_HSurfaceTool.VPeriod
Adaptor3d_HSurfaceTool_VResolution = Adaptor3d_HSurfaceTool.VResolution
Adaptor3d_HSurfaceTool_VTrim = Adaptor3d_HSurfaceTool.VTrim
Adaptor3d_HSurfaceTool_Value = Adaptor3d_HSurfaceTool.Value



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Geom import *
from OCC.Core.GeomAbs import *
from OCC.Core.Geom2d import *
from OCC.Core.TopAbs import *
from OCC.Core.TopTools import *
from OCC.Core.TopoDS import *
from OCC.Core.gp import *
from OCC.Core.TColStd import *
from OCC.Core.BRepBuilderAPI import *
from OCC.Core.TColgp import *
from OCC.Core.ShapeAnalysis import *
from OCC.Core.ShapeExtend import *


class shapeconstruct:
	@overload
	@staticmethod
	def ConvertCurveToBSpline(C3D: Geom_Curve, First: float, Last: float, Tol3d: float, Continuity: GeomAbs_Shape, MaxSegments: int, MaxDegree: int) -> Geom_BSplineCurve: ...
	@overload
	@staticmethod
	def ConvertCurveToBSpline(C2D: Geom2d_Curve, First: float, Last: float, Tol2d: float, Continuity: GeomAbs_Shape, MaxSegments: int, MaxDegree: int) -> Geom2d_BSplineCurve: ...
	@staticmethod
	def ConvertSurfaceToBSpline(surf: Geom_Surface, UF: float, UL: float, VF: float, VL: float, Tol3d: float, Continuity: GeomAbs_Shape, MaxSegments: int, MaxDegree: int) -> Geom_BSplineSurface: ...
	@overload
	@staticmethod
	def JoinCurves(c3d1: Geom_Curve, ac3d2: Geom_Curve, Orient1: TopAbs_Orientation, Orient2: TopAbs_Orientation, c3dOut: Geom_Curve) -> Tuple[bool, float, float, float, float, bool, bool]: ...
	@overload
	@staticmethod
	def JoinCurves(c2d1: Geom2d_Curve, ac2d2: Geom2d_Curve, Orient1: TopAbs_Orientation, Orient2: TopAbs_Orientation, c2dOut: Geom2d_Curve, isError: Optional[bool] = False) -> Tuple[bool, float, float, float, float, bool, bool]: ...
	@staticmethod
	def JoinPCurves(theEdges: TopTools_HSequenceOfShape, theFace: TopoDS_Face, theEdge: TopoDS_Edge) -> bool: ...

class ShapeConstruct_Curve:
	def AdjustCurve(self, C3D: Geom_Curve, P1: gp_Pnt, P2: gp_Pnt, take1: Optional[bool] = True, take2: Optional[bool] = True) -> bool: ...
	def AdjustCurve2d(self, C2D: Geom2d_Curve, P1: gp_Pnt2d, P2: gp_Pnt2d, take1: Optional[bool] = True, take2: Optional[bool] = True) -> bool: ...
	def AdjustCurveSegment(self, C3D: Geom_Curve, P1: gp_Pnt, P2: gp_Pnt, U1: float, U2: float) -> bool: ...
	@overload
	def ConvertToBSpline(self, C: Geom_Curve, first: float, last: float, prec: float) -> Geom_BSplineCurve: ...
	@overload
	def ConvertToBSpline(self, C: Geom2d_Curve, first: float, last: float, prec: float) -> Geom2d_BSplineCurve: ...
	@overload
	@staticmethod
	def FixKnots(knots: TColStd_HArray1OfReal) -> bool: ...
	@overload
	@staticmethod
	def FixKnots(knots: TColStd_Array1OfReal) -> bool: ...

class ShapeConstruct_MakeTriangulation(BRepBuilderAPI_MakeShape):
	@overload
	def __init__(self, pnts: TColgp_Array1OfPnt, prec: Optional[float] = 0.0) -> None: ...
	@overload
	def __init__(self, wire: TopoDS_Wire, prec: Optional[float] = 0.0) -> None: ...
	def Build(self) -> None: ...
	def IsDone(self) -> bool: ...

class ShapeConstruct_ProjectCurveOnSurface(Standard_Transient):
	def __init__(self) -> None: ...
	def GetAdjustOverDegenMode(self) -> int: ...
	def SetAdjustOverDegenMode(self, value: int) -> None: ...
	def GetBuildCurveMode(self) -> bool: ...
	def SetBuildCurveMode(self, value: bool) -> None: ...
	@overload
	def Init(self, surf: Geom_Surface, preci: float) -> None: ...
	@overload
	def Init(self, surf: ShapeAnalysis_Surface, preci: float) -> None: ...
	def Perform(self, c3d: Geom_Curve, First: float, Last: float, c2d: Geom2d_Curve, TolFirst: Optional[float] = -1, TolLast: Optional[float] = -1) -> bool: ...
	def PerformByProjLib(self, c3d: Geom_Curve, First: float, Last: float, c2d: Geom2d_Curve, continuity: Optional[GeomAbs_Shape] = GeomAbs_C1, maxdeg: Optional[int] = 12, nbinterval: Optional[int] = -1) -> bool: ...
	def SetPrecision(self, preci: float) -> None: ...
	@overload
	def SetSurface(self, surf: Geom_Surface) -> None: ...
	@overload
	def SetSurface(self, surf: ShapeAnalysis_Surface) -> None: ...
	def Status(self, theStatus: ShapeExtend_Status) -> bool: ...

# harray1 classes
# harray2 classes
# hsequence classes

shapeconstruct_ConvertCurveToBSpline = shapeconstruct.ConvertCurveToBSpline
shapeconstruct_ConvertCurveToBSpline = shapeconstruct.ConvertCurveToBSpline
shapeconstruct_ConvertSurfaceToBSpline = shapeconstruct.ConvertSurfaceToBSpline
shapeconstruct_JoinCurves = shapeconstruct.JoinCurves
shapeconstruct_JoinCurves = shapeconstruct.JoinCurves
shapeconstruct_JoinPCurves = shapeconstruct.JoinPCurves
ShapeConstruct_Curve_FixKnots = ShapeConstruct_Curve.FixKnots
ShapeConstruct_Curve_FixKnots = ShapeConstruct_Curve.FixKnots



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
Geom2dLProp module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_geom2dlprop.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _Geom2dLProp
else:
    import _Geom2dLProp

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _Geom2dLProp.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _Geom2dLProp.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Geom2dLProp.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Geom2dLProp.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _Geom2dLProp.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _Geom2dLProp.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _Geom2dLProp.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _Geom2dLProp.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _Geom2dLProp.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _Geom2dLProp.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Geom2dLProp.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _Geom2dLProp.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _Geom2dLProp.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Geom2dLProp.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Geom2dLProp.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Geom2dLProp.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _Geom2dLProp.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _Geom2dLProp:
_Geom2dLProp.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _Geom2dLProp.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Geom2d
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.LProp
import OCC.Core.math
import OCC.Core.Message
import OCC.Core.OSD

from enum import IntEnum
from OCC.Core.Exception import *



class Geom2dLProp_CLProps2d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initializes the local properties of the curve <c> the current point and the derivatives are computed at the same time, which allows an optimization of the computation time. <n> indicates the maximum number of derivations to be done (0, 1, 2 or 3). for example, to compute only the tangent, n should be equal to 1. <resolution> is the linear tolerance (it is used to test if a vector is null).

        Parameters
        ----------
        C: Geom2d_Curve
        N: int
        Resolution: float

        Returns
        -------
        None
        Same as previous constructor but here the parameter is set to the value <u>. all the computations done will be related to <c> and <u>.

        Parameters
        ----------
        C: Geom2d_Curve
        U: float
        N: int
        Resolution: float

        Returns
        -------
        None
        Same as previous constructor but here the parameter is set to the value <u> and the curve is set with setcurve. the curve can have a empty constructor all the computations done will be related to <c> and <u> when the functions 'set' will be done.

        Parameters
        ----------
        N: int
        Resolution: float

        Returns
        -------
        None

        """
        _Geom2dLProp.Geom2dLProp_CLProps2d_swiginit(self, _Geom2dLProp.new_Geom2dLProp_CLProps2d(*args))

    def CentreOfCurvature(self, *args) -> "void":
        r"""
        Returns the centre of curvature <p>.

        Parameters
        ----------
        P: gp_Pnt2d

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_CentreOfCurvature(self, *args)

    def Curvature(self, *args) -> "Standard_Real":
        r"""
        Returns the curvature.

        Returns
        -------
        float

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_Curvature(self, *args)

    def D1(self, *args) -> "gp_Vec2d const":
        r"""
        Returns the first derivative. the derivative is computed if it has not been yet.

        Returns
        -------
        gp_Vec2d

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_D1(self, *args)

    def D2(self, *args) -> "gp_Vec2d const":
        r"""
        Returns the second derivative. the derivative is computed if it has not been yet.

        Returns
        -------
        gp_Vec2d

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_D2(self, *args)

    def D3(self, *args) -> "gp_Vec2d const":
        r"""
        Returns the third derivative. the derivative is computed if it has not been yet.

        Returns
        -------
        gp_Vec2d

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_D3(self, *args)

    def IsTangentDefined(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the tangent is defined. for example, the tangent is not defined if the three first derivatives are all null.

        Returns
        -------
        bool

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_IsTangentDefined(self, *args)

    def Normal(self, *args) -> "void":
        r"""
        Returns the normal direction <n>.

        Parameters
        ----------
        N: gp_Dir2d

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_Normal(self, *args)

    def SetCurve(self, *args) -> "void":
        r"""
        Initializes the local properties of the curve for the new curve.

        Parameters
        ----------
        C: Geom2d_Curve

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_SetCurve(self, *args)

    def SetParameter(self, *args) -> "void":
        r"""
        Initializes the local properties of the curve for the parameter value <u>.

        Parameters
        ----------
        U: float

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_SetParameter(self, *args)

    def Tangent(self, *args) -> "void":
        r"""
        Output the tangent direction <d>.

        Parameters
        ----------
        D: gp_Dir2d

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_Tangent(self, *args)

    def Value(self, *args) -> "gp_Pnt2d const":
        r"""
        Returns the point.

        Returns
        -------
        gp_Pnt2d

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Geom2dLProp.delete_Geom2dLProp_CLProps2d

# Register Geom2dLProp_CLProps2d in _Geom2dLProp:
_Geom2dLProp.Geom2dLProp_CLProps2d_swigregister(Geom2dLProp_CLProps2d)

class Geom2dLProp_CurAndInf2d(OCC.Core.LProp.LProp_CurAndInf):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initializes the framework. note: the curve on which the local properties are computed is defined using one of the following functions: perform, performcurext or performinf.

        Returns
        -------
        None

        """
        _Geom2dLProp.Geom2dLProp_CurAndInf2d_swiginit(self, _Geom2dLProp.new_Geom2dLProp_CurAndInf2d(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        True if the solutions are found.

        Returns
        -------
        bool

        """
        return _Geom2dLProp.Geom2dLProp_CurAndInf2d_IsDone(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        For the curve c, computes both the inflection points and the maximum and minimum curvatures.

        Parameters
        ----------
        C: Geom2d_Curve

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_CurAndInf2d_Perform(self, *args)

    def PerformCurExt(self, *args) -> "void":
        r"""
        For the curve c, computes the locals extremas of curvature.

        Parameters
        ----------
        C: Geom2d_Curve

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_CurAndInf2d_PerformCurExt(self, *args)

    def PerformInf(self, *args) -> "void":
        r"""
        For the curve c, computes the inflections. after computation, the following functions can be used: - isdone to check if the computation was successful - nbpoints to obtain the number of computed particular points - parameter to obtain the parameter on the curve for each particular point - type to check if the point is an inflection point or an extremum of curvature of the curve c. warning these functions can be used to analyze a series of curves, however it is necessary to clear the table of results between each computation.

        Parameters
        ----------
        C: Geom2d_Curve

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_CurAndInf2d_PerformInf(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Geom2dLProp.delete_Geom2dLProp_CurAndInf2d

# Register Geom2dLProp_CurAndInf2d in _Geom2dLProp:
_Geom2dLProp.Geom2dLProp_CurAndInf2d_swigregister(Geom2dLProp_CurAndInf2d)

class Geom2dLProp_Curve2dTool(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Continuity(*args) -> "Standard_Integer":
        r"""
        Returns the order of continuity of the curve <c>. returns 1 : first derivative only is computable returns 2 : first and second derivative only are computable. returns 3 : first, second and third are computable.

        Parameters
        ----------
        C: Geom2d_Curve

        Returns
        -------
        int

        """
        return _Geom2dLProp.Geom2dLProp_Curve2dTool_Continuity(*args)

    @staticmethod
    def D1(*args) -> "void":
        r"""
        Computes the point <p> and first derivative <v1> of parameter <u> on the curve <c>.

        Parameters
        ----------
        C: Geom2d_Curve
        U: float
        P: gp_Pnt2d
        V1: gp_Vec2d

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_Curve2dTool_D1(*args)

    @staticmethod
    def D2(*args) -> "void":
        r"""
        Computes the point <p>, the first derivative <v1> and second derivative <v2> of parameter <u> on the curve <c>.

        Parameters
        ----------
        C: Geom2d_Curve
        U: float
        P: gp_Pnt2d
        V1: gp_Vec2d
        V2: gp_Vec2d

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_Curve2dTool_D2(*args)

    @staticmethod
    def D3(*args) -> "void":
        r"""
        Computes the point <p>, the first derivative <v1>, the second derivative <v2> and third derivative <v3> of parameter <u> on the curve <c>.

        Parameters
        ----------
        C: Geom2d_Curve
        U: float
        P: gp_Pnt2d
        V1: gp_Vec2d
        V2: gp_Vec2d
        V3: gp_Vec2d

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_Curve2dTool_D3(*args)

    @staticmethod
    def FirstParameter(*args) -> "Standard_Real":
        r"""
        Returns the first parameter bound of the curve.

        Parameters
        ----------
        C: Geom2d_Curve

        Returns
        -------
        float

        """
        return _Geom2dLProp.Geom2dLProp_Curve2dTool_FirstParameter(*args)

    @staticmethod
    def LastParameter(*args) -> "Standard_Real":
        r"""
        Returns the last parameter bound of the curve. firstparameter must be less than lastparameter.

        Parameters
        ----------
        C: Geom2d_Curve

        Returns
        -------
        float

        """
        return _Geom2dLProp.Geom2dLProp_Curve2dTool_LastParameter(*args)

    @staticmethod
    def Value(*args) -> "void":
        r"""
        Computes the point <p> of parameter <u> on the curve <c>.

        Parameters
        ----------
        C: Geom2d_Curve
        U: float
        P: gp_Pnt2d

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_Curve2dTool_Value(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _Geom2dLProp.Geom2dLProp_Curve2dTool_swiginit(self, _Geom2dLProp.new_Geom2dLProp_Curve2dTool())
    __swig_destroy__ = _Geom2dLProp.delete_Geom2dLProp_Curve2dTool

# Register Geom2dLProp_Curve2dTool in _Geom2dLProp:
_Geom2dLProp.Geom2dLProp_Curve2dTool_swigregister(Geom2dLProp_Curve2dTool)

def Geom2dLProp_Curve2dTool_Continuity(*args) -> "Standard_Integer":
    r"""
    Returns the order of continuity of the curve <c>. returns 1 : first derivative only is computable returns 2 : first and second derivative only are computable. returns 3 : first, second and third are computable.

    Parameters
    ----------
    C: Geom2d_Curve

    Returns
    -------
    int

    """
    return _Geom2dLProp.Geom2dLProp_Curve2dTool_Continuity(*args)

def Geom2dLProp_Curve2dTool_D1(*args) -> "void":
    r"""
    Computes the point <p> and first derivative <v1> of parameter <u> on the curve <c>.

    Parameters
    ----------
    C: Geom2d_Curve
    U: float
    P: gp_Pnt2d
    V1: gp_Vec2d

    Returns
    -------
    None

    """
    return _Geom2dLProp.Geom2dLProp_Curve2dTool_D1(*args)

def Geom2dLProp_Curve2dTool_D2(*args) -> "void":
    r"""
    Computes the point <p>, the first derivative <v1> and second derivative <v2> of parameter <u> on the curve <c>.

    Parameters
    ----------
    C: Geom2d_Curve
    U: float
    P: gp_Pnt2d
    V1: gp_Vec2d
    V2: gp_Vec2d

    Returns
    -------
    None

    """
    return _Geom2dLProp.Geom2dLProp_Curve2dTool_D2(*args)

def Geom2dLProp_Curve2dTool_D3(*args) -> "void":
    r"""
    Computes the point <p>, the first derivative <v1>, the second derivative <v2> and third derivative <v3> of parameter <u> on the curve <c>.

    Parameters
    ----------
    C: Geom2d_Curve
    U: float
    P: gp_Pnt2d
    V1: gp_Vec2d
    V2: gp_Vec2d
    V3: gp_Vec2d

    Returns
    -------
    None

    """
    return _Geom2dLProp.Geom2dLProp_Curve2dTool_D3(*args)

def Geom2dLProp_Curve2dTool_FirstParameter(*args) -> "Standard_Real":
    r"""
    Returns the first parameter bound of the curve.

    Parameters
    ----------
    C: Geom2d_Curve

    Returns
    -------
    float

    """
    return _Geom2dLProp.Geom2dLProp_Curve2dTool_FirstParameter(*args)

def Geom2dLProp_Curve2dTool_LastParameter(*args) -> "Standard_Real":
    r"""
    Returns the last parameter bound of the curve. firstparameter must be less than lastparameter.

    Parameters
    ----------
    C: Geom2d_Curve

    Returns
    -------
    float

    """
    return _Geom2dLProp.Geom2dLProp_Curve2dTool_LastParameter(*args)

def Geom2dLProp_Curve2dTool_Value(*args) -> "void":
    r"""
    Computes the point <p> of parameter <u> on the curve <c>.

    Parameters
    ----------
    C: Geom2d_Curve
    U: float
    P: gp_Pnt2d

    Returns
    -------
    None

    """
    return _Geom2dLProp.Geom2dLProp_Curve2dTool_Value(*args)

class Geom2dLProp_FuncCurExt(OCC.Core.math.math_FunctionWithDerivative):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        C: Geom2d_Curve
        Tol: float

        Returns
        -------
        None

        """
        _Geom2dLProp.Geom2dLProp_FuncCurExt_swiginit(self, _Geom2dLProp.new_Geom2dLProp_FuncCurExt(*args))

    def IsMinKC(self, *args) -> "Standard_Boolean":
        r"""
        True if param corresponds to a minus of the radius of curvature.

        Parameters
        ----------
        Param: float

        Returns
        -------
        bool

        """
        return _Geom2dLProp.Geom2dLProp_FuncCurExt_IsMinKC(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Geom2dLProp.delete_Geom2dLProp_FuncCurExt

# Register Geom2dLProp_FuncCurExt in _Geom2dLProp:
_Geom2dLProp.Geom2dLProp_FuncCurExt_swigregister(Geom2dLProp_FuncCurExt)

class Geom2dLProp_FuncCurNul(OCC.Core.math.math_FunctionWithDerivative):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        C: Geom2d_Curve

        Returns
        -------
        None

        """
        _Geom2dLProp.Geom2dLProp_FuncCurNul_swiginit(self, _Geom2dLProp.new_Geom2dLProp_FuncCurNul(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _Geom2dLProp.delete_Geom2dLProp_FuncCurNul

# Register Geom2dLProp_FuncCurNul in _Geom2dLProp:
_Geom2dLProp.Geom2dLProp_FuncCurNul_swigregister(Geom2dLProp_FuncCurNul)

class Geom2dLProp_NumericCurInf2d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _Geom2dLProp.Geom2dLProp_NumericCurInf2d_swiginit(self, _Geom2dLProp.new_Geom2dLProp_NumericCurInf2d(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        True if the solutions are found.

        Returns
        -------
        bool

        """
        return _Geom2dLProp.Geom2dLProp_NumericCurInf2d_IsDone(self, *args)

    def PerformCurExt(self, *args) -> "void":
        r"""
        Computes the locals extremas of curvature.

        Parameters
        ----------
        C: Geom2d_Curve
        Result: LProp_CurAndInf

        Returns
        -------
        None
        Computes the locals extremas of curvature. in the interval of parmeters [umin,umax].

        Parameters
        ----------
        C: Geom2d_Curve
        UMin: float
        UMax: float
        Result: LProp_CurAndInf

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_NumericCurInf2d_PerformCurExt(self, *args)

    def PerformInf(self, *args) -> "void":
        r"""
        Computes the inflections.

        Parameters
        ----------
        C: Geom2d_Curve
        Result: LProp_CurAndInf

        Returns
        -------
        None
        Computes the inflections in the interval of parmeters [umin,umax].

        Parameters
        ----------
        C: Geom2d_Curve
        UMin: float
        UMax: float
        Result: LProp_CurAndInf

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_NumericCurInf2d_PerformInf(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Geom2dLProp.delete_Geom2dLProp_NumericCurInf2d

# Register Geom2dLProp_NumericCurInf2d in _Geom2dLProp:
_Geom2dLProp.Geom2dLProp_NumericCurInf2d_swigregister(Geom2dLProp_NumericCurInf2d)





